<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * MonsterInsights PPC Tracking - WooCommerce tracking class.
 *
 * @access public
 * @since 2.0.0
 *
 * @package MonsterInsights_PPC_Tracking
 * @subpackage Ecommerce_Providers
 * @author  David Paternina
 */

class MonsterInsights_PPC_Tracking_Ecommerce_Lifter_LMS extends MonsterInsights_PPC_Tracking_Ecommerce_Tracking
{
    /**
     * LifterLMS order
     *
     * @var $order LLMS_Order
     */
    protected $order;

    /**
     * @inheritdoc
     */
    public function do_conversion_checks() {
        global $wp;
        return is_llms_account_page() && !empty( $wp->query_vars['orders'] );
    }

    /**
     * @inheritdoc
     */
    public function is_active() {
        return function_exists( 'LLMS' ) &&
            version_compare( LLMS()->version, '3.32.0', '>=' ) &&
            apply_filters( 'MonsterInsights_PPC_Tracking_track_conversion_lifterlms', true );
    }

    /**
     * @inheritdoc
     */
    public function try_to_get_order() {

        global $wp;

        $order_id = $wp->query_vars['orders'];

        if ( empty( $order_id ) ) {
            return false;
        }

        $this->order = new LLMS_Order( $order_id );
        return true;
    }

    /**
     * @inheritDoc
     */
    function get_order_total() {
        return empty( $this->order ) ? null : $this->order->total;
    }

    /**
     * @inheritDoc
     */
    function get_order_currency() {
        return empty( $this->order ) ? null : $this->order->currency;
    }

    /**
     * @inheritDoc
     */
    function get_order_number() {
        return empty( $this->order ) ? null : $this->order->id;
    }

    /**
     * @inheritDoc
     */
    function already_tracked( $provider_id ) {
        if ( empty( $this->order ) ) {
            return true;
        }

        $tracked = get_post_meta( $this->order->id, "_MonsterInsights_PPC_Tracking_conversion_tracked_{$provider_id}", true );

        return ! empty( $tracked ) && 'yes' === $tracked;
    }

    /**
     * @inheritDoc
     */
    function mark_order_tracked( $provider_id ) {
        if ( empty( $this->order ) ) {
            return;
        }

        update_post_meta( $this->order->id, "_MonsterInsights_PPC_Tracking_conversion_tracked_{$provider_id}", 'yes' );
    }

    /**
     * @inheritdoc
     */
    public function get_name()
    {
        return 'LifterLMS';
    }
}
