<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * MonsterInsights PPC Tracking - MemberPress tracking class.
 *
 * @access public
 * @since 2.0.0
 *
 * @package MonsterInsights_PPC_Tracking
 * @subpackage Ecommerce_Providers
 * @author  David Paternina
 */

class MonsterInsights_PPC_Tracking_Ecommerce_MemberPress extends MonsterInsights_PPC_Tracking_Ecommerce_Tracking
{
    /**
     * MemberPress order
     *
     * @var $order MeprTransaction|MeprSubscription
     */
    protected $order;

    /**
     * MemberPress order/transaction id
     *
     * @var $order_id String
     */
    private $order_id;

    /**
     * @inheritdoc
     */
    public function do_conversion_checks() {

        if ( isset( $_GET['trans_num'] ) ) {
            return true;
        }

        if ( isset( $_GET['action'] ) && $_GET['action'] === 'gifts' && isset( $_GET['txn'] ) ) {
            $txn = new MeprTransaction( (int) $_GET['txn'] );
            if ( $txn->id ) {
                $_REQUEST['trans_num'] = $txn->trans_num;
                return true;
            }
        }

        return false;
    }

    /**
     * @inheritdoc
     */
    public function is_active() {
        return defined( 'MEPR_VERSION' ) &&
            version_compare( MEPR_VERSION, '1.3.43', '>' ) &&
            apply_filters( 'MonsterInsights_PPC_Tracking_track_conversion_memberpress', true );
    }

    /**
     * @inheritdoc
     */
    public function try_to_get_order() {
        if ( empty( $_REQUEST['trans_num'] ) ) {
            return false;
        }

        if ( empty( $_REQUEST['subscr_id'] ) ) {
            $txn  = new MeprTransaction();
            $data = MeprTransaction::get_one_by_trans_num( sanitize_key( $_REQUEST['trans_num'] ) );
            $txn->load_data( $data );

            if ( ! $txn->id || ! $txn->product_id ) {
                return false;
            }

            $this->order    = $txn;
            $this->order_id = 'charge_' . $txn->id;

            return true;
        }

        $sub = MeprSubscription::get_one_by_subscr_id( sanitize_key( $_REQUEST['subscr_id'] ) );
        if ( $sub === false || ! $sub->id || ! $sub->product_id ) {
            return false;
        }
        $this->order    = $sub;
        $this->order_id = 'sub_' . $sub->id;

        return true;
    }

    /**
     * @inheritDoc
     */
    function get_order_total() {

        if ( empty( $this->order ) ) {
            return null;
        }

        if ( $this->order instanceof MeprSubscription ) {
            return $this->order->trial ? $this->order->trial_total : $this->order->total;
        } else {
            return $this->order->total;
        }
    }

    /**
     * @inheritDoc
     */
    function get_order_currency() {
        $mepr_options = MeprOptions::fetch();

        return $mepr_options->currency_code;
    }

    /**
     * @inheritDoc
     */
    function get_order_number() {
        return empty( $this->order_id ) ? null : $this->order_id;
    }

    /**
     * @inheritDoc
     */
    function already_tracked( $provider_id ) {
        if ( empty( $this->order ) ) {
            return true;
        }

        $tracked = $this->order->get_meta( "_MonsterInsights_PPC_Tracking_conversion_tracked_{$provider_id}", true );

        return ! empty( $tracked ) && 'yes' === $tracked;
    }

    /**
     * @inheritDoc
     */
    function mark_order_tracked( $provider_id ) {
        if ( empty( $this->order ) ) {
            return;
        }

        $this->order->update_meta( "_MonsterInsights_PPC_Tracking_conversion_tracked_{$provider_id}", 'yes' );
    }

    /**
     * @inheritdoc
     */
    public function get_name()
    {
        return 'MemberPress';
    }
}
